# Generated by Django 3.1.4 on 2021-01-13 17:44

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0144_auto_20210112_1440'),
        ('djconnectwise', '0144_contactcommunication_default_flag'),
    ]

    operations = [
    ]
