# Generated by Django 2.1.14 on 2019-12-20 13:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0111_auto_20191204_0838'),
    ]

    operations = [
        migrations.AddField(
            model_name='syncjob',
            name='synchronizer_class',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
    ]
