# Generated by Django 2.0.6 on 2018-06-07 12:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0060_auto_20180605_0840'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='opportunitynote',
            options={'ordering': ('-date_created', 'id'), 'verbose_name_plural': 'Opportunity notes'},
        ),
        migrations.AlterModelOptions(
            name='team',
            options={'ordering': ('name', 'id'), 'verbose_name_plural': 'Teams'},
        ),
        migrations.AlterModelOptions(
            name='timeentry',
            options={'ordering': ('-time_start', 'id'), 'verbose_name_plural': 'Time entries'},
        ),
        migrations.AddField(
            model_name='timeentry',
            name='detail_description_flag',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='timeentry',
            name='internal_analysis_flag',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='timeentry',
            name='resolution_flag',
            field=models.BooleanField(default=False),
        ),
    ]
