# Generated by Django 3.1.5 on 2021-03-17 14:24

from django.db import migrations, models
from django.db.migrations import RunPython


def delete_null_value_rows(apps, schema_editor):
    ContactCommunication = apps.get_model(
        'djconnectwise', 'ContactCommunication')
    queryset = ContactCommunication.objects.filter(value__isnull=True)
    queryset.delete()
    queryset = ContactCommunication.objects.filter(value__exact='')
    queryset.delete()


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0147_auto_20210223_1752'),
    ]

    operations = [
        migrations.RunPython(
            delete_null_value_rows, RunPython.noop
        ),
        migrations.AlterField(
            model_name='contactcommunication',
            name='value',
            field=models.CharField(max_length=250),
        ),
    ]
