# Generated by Django 2.2 on 2019-04-04 15:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0083_delete_callbackentry'),
    ]

    operations = [
        migrations.AlterField(
            model_name='servicenote',
            name='detail_description_flag',
            field=models.BooleanField(blank=True),
        ),
        migrations.AlterField(
            model_name='servicenote',
            name='external_flag',
            field=models.BooleanField(blank=True),
        ),
        migrations.AlterField(
            model_name='servicenote',
            name='internal_analysis_flag',
            field=models.BooleanField(blank=True),
        ),
        migrations.AlterField(
            model_name='servicenote',
            name='internal_flag',
            field=models.BooleanField(blank=True),
        ),
        migrations.AlterField(
            model_name='servicenote',
            name='resolution_flag',
            field=models.BooleanField(blank=True),
        ),
    ]
