# Generated by Django 3.1.2 on 2020-12-08 11:16

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djconnectwise', '0137_auto_20201201_1042'),
    ]

    operations = [
        migrations.CreateModel(
            name='Contact',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('first_name', models.TextField(blank=True, max_length=30, null=True)),
                ('last_name', models.TextField(blank=True, max_length=30, null=True)),
                ('address_line1', models.CharField(blank=True, max_length=250, null=True)),
                ('address_line2', models.CharField(blank=True, max_length=250, null=True)),
                ('city', models.CharField(blank=True, max_length=250, null=True)),
                ('state_identifier', models.CharField(blank=True, max_length=250, null=True)),
                ('zip', models.CharField(blank=True, max_length=250, null=True)),
                ('company', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='djconnectwise.company')),
            ],
        ),
        migrations.CreateModel(
            name='ContactCommunication',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.CharField(blank=True, max_length=250, null=True)),
                ('contact_id', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='djconnectwise.contact')),
            ],
        ),
        migrations.CreateModel(
            name='ContactCommunicationTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_contactcommunication',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.contactcommunication',),
        ),
        migrations.CreateModel(
            name='ContactTracker',
            fields=[
            ],
            options={
                'db_table': 'djconnectwise_contact',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djconnectwise.contact',),
        ),
    ]
